// Planck Distribution Functions
// Jeffrey J Weimer
// 2008.May.30

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version = 1.11

// Physical Constants

Static Constant h = 6.62606896E-34
Static Constant k = 1.3806504E-23
Static Constant c = 2.99792548E8

// Support Functions

// Wavelength Form
// lambda: wavelength in nm
// TK: temperature in K

Function PlanckDistL(lambda, TK)
	variable lambda, TK
	
	variable rho, ex, lm
	
	lm = lambda*1e-9
	
	ex = exp(-h*c/(lm*k*TK))
	
	rho = (2*h*c^2/lm^5)*ex/(1-ex)
	
	return rho

end

// Frequency Form
// nu: frequency in Hz
// TK: temperature in K

Function PlanckDistN(nu, TK)
	variable nu, TK
	
	variable rho, ex
	
	ex = exp(-h*nu/(k*TK))
	
	rho = (2*h*nu^3/c^2)*ex/(1-ex)
	
	return rho

end